@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Field::Attribute;
 use vars '$VERSION';
-$VERSION = '2.104';
+$VERSION = '2.105';
 
 use base 'Mail::Reporter';
 use 5.007003;
@@ -16,6 +16,18 @@ use Encode ();
 use Carp;
 
 
+use Carp 'cluck';
+use overload
+    '""' => sub {shift->value}
+  , cmp  => sub { my ($self, $other) = @_;
+      UNIVERSAL::isa($other, 'Mail::Message::Field')
+        ? (lc($_[0])->name cmp lc($_[1]->name) || $_[0]->value cmp $_[1]->value)
+        : $_[0]->value cmp $_[1]
+        }
+  , fallback => 1;
+
+
+
 sub new($$@)
 {   my ($class, $attr) = (shift, shift);
     my $value = @_ % 2 == 1 ? shift : undef;
@@ -37,7 +49,7 @@ sub init($$)
     $self->{MMFF_charset}  = $args->{charset}  if defined $args->{charset};
     $self->{MMFF_language} = $args->{language} if defined $args->{language};
 
-    $self->value($value)       if defined $value;
+    $self->value(defined $value ? $value : '');
     $self->addComponent($attr) unless $attr eq $name;
 
     $self;
@@ -55,7 +67,6 @@ sub value(;$)
     {   delete $self->{MMFF_cont};
         return $self->{MMFF_value} = shift;
     }
-      
     exists $self->{MMFF_value} ? $self->{MMFF_value} : $self->decode;
 }
 
@@ -193,7 +204,7 @@ sub decode()
 sub mergeComponent($)
 {   my ($self, $comp) = @_;
     my $cont  = $self->{MMFF_cont}
-       or croak "ERROR: Too late to merge: value already changed.";
+        or croak "ERROR: Too late to merge: value already changed.";
 
     defined $_ && $self->addComponent($_)
         foreach @{$comp->{MMFF_cont}};
